pub struct PasswordHash {
pub algorithm: Ident,
pub version: Option<u32>,
pub params: ParamsString,
pub salt: Option<Salt>,
pub hash: Option<Output>,
}Expand description
Password hash.
This type corresponds to the parsed representation of a PHC string as described in the PHC string format specification.
PHC strings have the following format:
$<id>[$v=<version>][$<param>=<value>(,<param>=<value>)*][$<salt>[$<hash>]]where:
<id>is the symbolic name for the function<version>is the algorithm version<param>is a parameter name<value>is a parameter value<salt>is an encoding of the salt<hash>is an encoding of the hash output
The string is then the concatenation, in that order, of:
- a
$sign; - the function symbolic name;
- optionally, a
$sign followed by the algorithm version with av=versionformat; - optionally, a
$sign followed by one or several parameters, each with aname=valueformat; the parameters are separated by commas; - optionally, a
$sign followed by the (encoded) salt value; - optionally, a
$sign followed by the (encoded) hash output (the hash output may be present only if the salt is present).
Fields
algorithm: IdentPassword hashing algorithm identifier.
This corresponds to the <id> field in a PHC string, a.k.a. the
symbolic name for the function.
version: Option<u32>Optional version field.
This corresponds to the <version> field in a PHC string.
params: ParamsStringAlgorithm-specific parameters.
This corresponds to the set of $<param>=<value>(,<param>=<value>)*
name/value pairs in a PHC string.
salt: Option<Salt>Salt string for personalizing a password hash output.
This corresponds to the <salt> value in a PHC string.
hash: Option<Output>Password hashing function Output, a.k.a. hash/digest.
This corresponds to the <hash> output in a PHC string.
Implementations
Sourceimpl PasswordHash
impl PasswordHash
Sourcepub fn new(s: &str) -> Result<PasswordHash, Error>
pub fn new(s: &str) -> Result<PasswordHash, Error>
Parse a password hash from a string in the PHC string format.
Sourcepub fn serialize(&self) -> PasswordHashString
👎Deprecated since 0.3.0: Use PasswordHash or String instead
pub fn serialize(&self) -> PasswordHashString
Use PasswordHash or String instead
DEPRECATED: serialize this PasswordHash as a PasswordHashString.